# Copyright 2024 The Spin Authors. All rights reserved.
# Use of this source code is governed by the Apache 2.0
# license that can be found in the LICENSE file.

from .times import now, python_time, time_from_python


def test_times():
    t = now()
    assert t == time_from_python(python_time(t))



# Copyright 2024 The Spin Authors. All rights reserved.
# Use of this source code is governed by the Apache 2.0
# license that can be found in the LICENSE file.

import datetime

"""
    Time represents a timestamp, in units of *micro*seconds,
    since the Unix epoch, Jan 1 1970 0:00 UTC.
"""
Time = int


def now() -> Time:
    """
    Returns the current time as a spin Time.
    """
    return time_from_python(datetime.datetime.now(tz=datetime.timezone.utc))


def python_time(t: Time) -> datetime.datetime:
    """
    Converts a spin Time to a Python datetime object.
    """
    return datetime.datetime.fromtimestamp(t / 1_000_000, tz=datetime.timezone.utc)


def time_from_python(t: datetime.datetime) -> Time:
    """
    Converts a Python datetime object to a spin Time.
    """
    return int(t.timestamp() * 1_000_000)



# Copyright 2024 The Spin Authors. All rights reserved.
# Use of this source code is governed by the Apache 2.0
# license that can be found in the LICENSE file.

__all__ = [
    "Name",
    "Path",
    "Time",
    "UUID",
    "now",
    "python_time",
    "time_from_python",
]

from .names import (
    Name,
)

from .paths import (
    Path,
)

from .times import (
    Time,
    now,
    python_time,
    time_from_python,
)

from .uuids import (
    UUID,
)



# Copyright 2024 The Spin Authors. All rights reserved.
# Use of this source code is governed by the Apache 2.0
# license that can be found in the LICENSE file.

"""
Path represents a spin path.
"""

Path = str



# Copyright 2024 The Spin Authors. All rights reserved.
# Use of this source code is governed by the Apache 2.0
# license that can be found in the LICENSE file.

"""The spinsys library.

The spinsys library provides tools for interacting with a Spin system.
"""

__version__ = "0.0.1"



# Copyright 2024 The Spin Authors. All rights reserved.
# Use of this source code is governed by the Apache 2.0
# license that can be found in the LICENSE file.

import uuid

"""
    UUID represents a spin UUID.

    We alias the uuid.UUID type for clarity and simplicity.
    This way, client code need only import and use the API
    of this module.
"""
UUID = uuid.UUID
